@@ -116,6 +116,10 @@ class FileCache():
         else:
             return self.default_engine.set_namespace(namespace=self.namespace).delete(key=key)
 
+    @runtime_logging
+    def exist(self, key):
+            return self.default_engine.set_namespace(namespace=self.namespace).exist(key=key)
+
     @runtime_logging
     def list_cache_objects(self):
         return self.default_engine.set_namespace(namespace=self.namespace).list_cache_objects()
